#-------------- This is a GNUPLOT configuration file for Skyglow plots formatting ------------ 
#
#---- Lines starting with #-sign are ignored. 
#---- Adding/removing the #-sign deactivate/activate corresponding GNUPLOT command.
#
splot "results.dat" with lines title "Skyglow:log-scale"     #data name and plot title, titla can be changed
#
#
#--- few settings where is nothing to change ----
#
#set logscale z                         #show levels in logarithmic scale, not used (Skyglow prepares logarithmic data), does not influence color map,isolines only
unset surf                              #no 3D surface plot, color map on base only
set view map                            #view perpendicularly to the map (base)
set size ratio -1                       #preserve aspect ratio of the plot
replot		                        #first redraw (not quite neccessary, from aesthetic reasons only - default plot is cleaned immediately)
set object 1 rectangle from screen 0,0 to screen 1,1 fillcolor rgb"white" #white background
#
#
#--- following parameters significantly influence the smoothness of the plot --------
#
set dgrid3d 90,90,8	                 #x- and y-density of regularly spaced points (plot resolution), smoothing (use "fast" values 1,2,4,8,16,...)
set pm3d		                      #do not change this line - we have to activate regular grid recalculation
set pm3d interpolate 1,1               #color smoothing parameters, larger numbers lead to longer calculations
#
#
#--- following parameters significantly influence the colors of the plot --------
#--- uncomment (remove the # character at the beginning of the row) one of the pre-defined palettes ---
#
set palette rgbformulae 7,5,15          #default color palette (black-blue-red-yellow)
#set palette rgbformulae 8,9,10         #color palette for B&W printing (blue-yellow)
#set palette rgbformulae 30,31,32       #another color palette for B&W printing (black-blue-magenta-yellow-white)
#set palette gray negative              #inverted greyscale palette
#
#
#--- following parameters control the isolines --------
#
set contour base                        #comment this line (put # at the beginning) if no isolines are requested
#set cntrparam levels 5                #aproximate number of isolines that will be automatically set
#set cntrparam levels discrete -15,-14,-13,-12,-11,-10,-9,-8,-7,-6,-5,-4,-3,-2,-1,0,1,2,3,4,5,6,7,8,9,10   #exact values of isolines
set cntrparam levels discrete -15,-14.5,-14,-13.5,-13,-12.5,-12,-11.5,-11,-10.5,-10,-9.5,-9,-8.5,-8,-7.5,-7,-6.5,-6,\
                              -5.5,-5,-4.5,-4,-3.5,-3,-2.5,-2,-1.5,-1,-0.5,0,0.5,1,1.5,2,2.5,3,3.5,4,4.5,5,5.5,6,6.5,\
                              7,7.5,8,8.5,9,9.5,10   #more dense isolines (exact values)
set cntrparam bspline                   #isolines draw method (linear, cubicspline, bspline)
set cntrparam order 10                  #smoothness of the isolines (use value 2...10)
#
#
#--- following parameters control the numbers in the legend --------
#
#set clabel '%.0e'                      #not used - e=scientific format, set decimal places: %.2e = 2 decimal places
set clabel '%.1f'                       #f=floating format, set decimal places: %.2f = 1 decimal place, %.0f = no decimal places (integer) 
#
#
#--- following parameters control the position of the legend --------
#
set key lmargin                            #position of the legend (left, right, top, bottom,lmargin, rmargin,tmargin,bmargin)
#unset key                               #hide legend
#set key at -110,90                       #exact position of the legend in the coordinate system of the plot
#
#
#--- following parameters control the z-axis (color) range --------
#
#set zrange [-8.1:-7.9]	                #z-scale of the plot (uncomment (remove #) this command if you want to limit the color values in the plot)
#set cbrange [-9:-5]	                #uncomment (remove #) this command to set fixed color scale (fixed range)
#
#
#--- there is nothing to change in following few commands --------
#
set xrange [-90.000000:90.000000]	#x-scale of the plot
set yrange [-90.000000:90.000000]	#y-scale of the plot
unset xtics                             #no ticks on x-axis
unset ytics                             #no ticks on y-axis
unset ylabel                            #no label at y-axis
unset border                            #no plot border
#
#
#--- Following lines hide the area behind the horizon ---------------
set object 2  polygon from \
90.000,0.000 to \
89.586,8.626 to \
89.658,7.844 to \
88.493,16.401 to \
88.633,15.628 to \
86.727,24.051 to \
86.933,23.294 to \
84.300,31.519 to \
84.572,30.782 to \
81.233,38.746 to \
81.568,38.036 to \
77.547,45.678 to \
77.942,45.000 to \
73.270,52.263 to \
73.724,51.622 to \
68.437,58.450 to \
68.944,57.851 to \
63.082,64.193 to \
63.640,63.640 to \
57.247,69.446 to \
57.851,68.944 to \
50.977,74.171 to \
51.622,73.724 to \
44.318,78.332 to \
45.000,77.942 to \
37.322,81.897 to \
38.036,81.568 to \
30.043,84.838 to \
30.782,84.572 to \
22.534,87.133 to \
23.294,86.933 to \
14.854,88.766 to \
15.628,88.633 to \
7.061,89.723 to \
7.844,89.658 to \
-0.785,89.997 to \
0.000,90.000 to \
-8.626,89.586 to \
-7.844,89.658  to \
-16.401,88.493 to \
-15.628,88.633  to \
-24.051,86.727  to \
-23.294,86.933 to \
-31.519,84.300 to \
-30.782,84.572 to \
-38.746,81.233 to \
-38.036,81.568  to \
-45.678,77.547  to \
-45.000,77.942  to \
-52.263,73.270  to \
-51.622,73.724  to \
-58.450,68.437  to \
-57.851,68.944  to \
-64.193,63.082  to \
-63.640,63.640  to \
-69.446,57.247  to \
-68.944,57.851  to \
-74.171,50.977  to \
-73.724,51.622  to \
-78.332,44.318  to \
-77.942,45.000  to \
-81.897,37.322  to \
-81.568,38.036  to \
-84.838,30.043  to \
-84.572,30.782  to \
-87.133,22.534  to \
-86.933,23.294  to \
-88.766,14.854  to \
-88.633,15.628  to \
-89.723,7.061  to \
-89.658,7.844  to \
-89.997,-0.785  to \
-90.000,0.000  to \
-89.586,-8.626  to \
-89.658,-7.844  to \
-88.493,-16.401  to \
-88.633,-15.628  to \
-86.727,-24.051  to \
-86.933,-23.294  to \
-84.300,-31.519  to \
-84.572,-30.782  to \
-81.233,-38.746  to \
-81.568,-38.036  to \
-77.547,-45.678  to \
-77.942,-45.000  to \
-73.270,-52.263  to \
-73.724,-51.622  to \
-68.437,-58.450  to \
-68.944,-57.851  to \
-63.082,-64.193  to \
-63.640,-63.640  to \
-57.247,-69.446  to \
-57.851,-68.944  to \
-50.977,-74.171  to \
-51.622,-73.724  to \
-44.318,-78.332  to \
-45.000,-77.942  to \
-37.322,-81.897  to \
-38.036,-81.568  to \
-30.043,-84.838  to \
-30.782,-84.572  to \
-22.534,-87.133  to \
-23.294,-86.933  to \
-14.854,-88.766  to \
-15.628,-88.633  to \
-7.061,-89.723  to \
-7.844,-89.658  to \
0.785,-89.997  to \
-0.000,-90.000  to \
8.626,-89.586  to \
7.844,-89.658  to \
16.401,-88.493  to \
15.628,-88.633  to \
24.051,-86.727  to \
23.294,-86.933  to \
31.519,-84.300  to \
30.782,-84.572  to \
38.746,-81.233  to \
38.036,-81.568  to \
45.678,-77.547  to \
45.000,-77.942  to \
52.263,-73.270  to \
51.622,-73.724  to \
58.450,-68.437  to \
57.851,-68.944  to \
64.193,-63.082  to \
63.640,-63.640  to \
69.446,-57.247  to \
68.944,-57.851  to \
74.171,-50.977  to \
73.724,-51.622  to \
78.332,-44.318  to \
77.942,-45.000  to \
81.897,-37.322  to \
81.568,-38.036  to \
84.838,-30.043  to \
84.572,-30.782  to \
87.133,-22.534  to \
86.933,-23.294  to \
88.766,-14.854  to \
88.633,-15.628  to \
89.723,-7.061  to \
89.658,-7.844  to \
89.997,0.785  to \
90.000, 0.000  to \
90.000,-90.000  to \
-90.000,-90.000  to \
-90.000,90.000  to \
90.000,90.000
set object 2 front fillcolor rgb "white" fillstyle solid border lw 6
#
#
#----- nothing to change in next two rows --------
unset mouse                         #deactivate mouse (and plot 3D-rotating)
replot                              #final redraw
#
#
#
#----- Following two sections produce color and b&w PNG files --------------
#
# Feel free to change parameters like picture size, font size, linewidth and so on
#
#--- Writes Portable Network Graphics (PNG) picture in full-colour ----------------
set terminal png size 1800,1024 linewidth 2 font ',24' 	#as on screen, picture size, font size and linewidth can be set
set output 'results_col.png'	     #picture filename 
replot 					     #write picture
unset output				     #close file
#--- End --------------------------------------------------------------------------

#
#--- Writes Portable Network Graphics (PNG) using black (labeled) isolines --------
set terminal png size 1800,1024 linewidth 3 font ',24' 	#picture size, font size and linewidth can be set
set monochrome                       #black isolines
set output 'results_bw.png'		    #picture filename 
unset pm3d                           #no color map
set cntrparam point 1                #labels density on the isolines, use 1,2,3,...
set cntrlabel  format '%.1f' font ',24' start 30 interval -1 #no. of decimal places, fontsize, starting position of labels on the isolines
set cntrlabel onecolor              #show only one line in the key (legend), all isolines have the same linetype
set style textbox opaque noborder    #white rectangle uder labels
unset object 2                       #no white line (nedded only for colormap)
set object 3 circle at 0,0 size 90  fs empty border rgb "black" linewidth 5   #black circle
splot "results.dat" with lines title "Skyglow:log-scale","results.dat" with labels boxed notitle     #data name and plot title
unset output				     #close file
#--- End --------------------------------------------------------------------------


